jupyter_jsmol: JSmol viewer widget for Jupyter
==============================================

Description
-----------

JSmol viewer widget for Jupyter

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/jupyter-jsmol/

